@@ -5,12 +5,13 @@ from os import chdir
 from pathlib import Path
 from typing import Dict, Optional, Tuple
 
-from solcx import compile_files
+import solcx
 
 from raiden_contracts.constants import PRECOMPILED_DATA_FIELDS, DeploymentModule
 from raiden_contracts.contract_manager import ContractManager, contracts_data_path
 
 _BASE = Path(__file__).parent
+SOLC_VERSION = "0.7.6"
 
 
 class ContractSourceManagerCompilationError(RuntimeError):
@@ -23,10 +24,10 @@ class ContractSourceManagerVerificationError(RuntimeError):
 
 
 class ContractSourceManager:
-    """ ContractSourceManager knows how to compile contracts """
+    """ContractSourceManager knows how to compile contracts"""
 
     def __init__(self, path: Dict[str, Path]) -> None:
-        """ Params: path: a dictionary of directories which contain solidity files to compile """
+        """Params: path: a dictionary of directories which contain solidity files to compile"""
         if not isinstance(path, dict):
             raise TypeError("Wrong type of argument given for ContractSourceManager()")
         self.contracts_source_dirs = path
@@ -38,6 +39,8 @@ class ContractSourceManager:
         and also the :ref:`ethereum.tools` python library.  The return value is a dict that
         should be written into contracts.json.
         """
+        solcx.install.install_solc(SOLC_VERSION)
+        solcx.set_solc_version(SOLC_VERSION)
         ret = {}
         old_working_dir = Path.cwd()
         chdir(_BASE)
@@ -51,23 +54,14 @@ class ContractSourceManager:
         import_dir_map.insert(0, ".=.")  # allow solc to compile contracts in all subdirs
         try:
             for contracts_dir in self.contracts_source_dirs.values():
-                res = compile_files(
+                res = solcx.compile_files(
                     [str(relativise(file)) for file in contracts_dir.glob("*.sol")],
-                    output_values=PRECOMPILED_DATA_FIELDS + ["ast"],
+                    output_values=PRECOMPILED_DATA_FIELDS,
                     import_remappings=import_dir_map,
-                    optimize=False,
+                    optimize=True,
+                    optimize_runs=200,
                 )
 
-                # Strip `ast` part from result
-                # TODO: Remove after https://github.com/ethereum/py-solc/issues/56 is fixed
-                res = {
-                    contract_name: {
-                        content_key: content_value
-                        for content_key, content_value in contract_content.items()
-                        if content_key != "ast"
-                    }
-                    for contract_name, contract_content in res.items()
-                }
                 ret.update(_fix_contract_key_names(res))
         except FileNotFoundError as ex:
             raise ContractSourceManagerCompilationError(
@@ -79,7 +73,7 @@ class ContractSourceManager:
         return ret
 
     def compile_contracts(self, target_path: Path) -> ContractManager:
-        """ Store compiled contracts JSON at `target_path`. """
+        """Store compiled contracts JSON at `target_path`."""
         assert self.overall_checksum is not None
 
         contracts_compiled = self._compile_all_contracts()
@@ -177,7 +171,7 @@ def _fix_contract_key_names(d: Dict) -> Dict:
 
 
 def check_runtime_codesize(d: Dict) -> None:
-    """ Raises a RuntimeError if the runtime codesize exceeds the EIP-170 limit """
+    """Raises a RuntimeError if the runtime codesize exceeds the EIP-170 limit"""
     for name, compilation in d.items():
         runtime_code_len = len(compilation["bin-runtime"]) // 2
         if runtime_code_len > 0x6000:
@@ -187,7 +181,7 @@ def check_runtime_codesize(d: Dict) -> None:
 def _verify_single_precompiled_checksum(
     checked_checksums: Dict[str, str], contract_name: str, expected_checksum: str
 ) -> None:
-    """ Get `checked_checksums[contract_name]` and compare it against `expected_checksum` """
+    """Get `checked_checksums[contract_name]` and compare it against `expected_checksum`"""
     try:
         precompiled_checksum = checked_checksums[contract_name]
     except KeyError:
@@ -195,12 +189,12 @@ def _verify_single_precompiled_checksum(
     if precompiled_checksum != expected_checksum:
         raise ContractSourceManagerVerificationError(
             f"checksum of {contract_name} does not match. got {precompiled_checksum} != "
-            "expected {expected_checksum}"
+            f"expected {expected_checksum}"
         )
 
 
 def verify_single_precompiled_checksum_on_nonexistent_contract_name() -> None:
-    """ A functiohn for testing the case where the contract name is not found """
+    """A functiohn for testing the case where the contract name is not found"""
     _verify_single_precompiled_checksum(
         checked_checksums={}, contract_name="a", expected_checksum="abc"
     )
