@@ -13,8 +13,6 @@ from raiden_contracts.constants import (
     CONTRACT_SERVICE_REGISTRY,
     CONTRACT_TOKEN_NETWORK_REGISTRY,
     CONTRACT_USER_DEPOSIT,
-    LIBRARY_TOKEN_NETWORK_UTILS,
-    LIBRARY_TOKEN_NETWORK_UTILS_LINK_KEY,
     DeploymentModule,
 )
 from raiden_contracts.contract_manager import (
@@ -24,7 +22,6 @@ from raiden_contracts.contract_manager import (
     contracts_precompiled_path,
     get_contracts_deployment_info,
 )
-from raiden_contracts.utils.linking import link_bytecode
 from raiden_contracts.utils.type_aliases import ChainID
 
 
@@ -181,7 +178,9 @@ class ContractVerifier:
         contracts = deployment_data["contracts"]
 
         # Check blockchain transaction hash & block information
-        receipt = self.web3.eth.getTransactionReceipt(contracts[contract_name]["transaction_hash"])
+        receipt = self.web3.eth.get_transaction_receipt(
+            contracts[contract_name]["transaction_hash"]
+        )
         if receipt["blockNumber"] != contracts[contract_name]["block_number"]:
             raise RuntimeError(
                 f'We have block_number {contracts[contract_name]["block_number"]} in the '
@@ -203,15 +202,6 @@ class ContractVerifier:
         blockchain_bytecode = self.web3.eth.get_code(contract_instance.address).hex()
         compiled_bytecode = self.contract_manager.get_runtime_hexcode(contract_name)
 
-        if contract_name == CONTRACT_TOKEN_NETWORK_REGISTRY:
-            # We need to link the libs into the contract bytecode.
-            # As this is run in the tests in fake file systems, do poor mans linking here
-            compiled_bytecode = link_bytecode(
-                unlinked_bytecode=compiled_bytecode,
-                library_identifier=LIBRARY_TOKEN_NETWORK_UTILS_LINK_KEY,
-                library_address=contracts[LIBRARY_TOKEN_NETWORK_UTILS]["address"],
-            )
-
         if blockchain_bytecode == compiled_bytecode:
             print(
                 f"{contract_name} at {contract_instance.address} "
@@ -301,7 +291,7 @@ def _verify_user_deposit_deployment(
     one_to_n_address: HexAddress,
     monitoring_service_address: HexAddress,
 ) -> None:
-    """ Check an onchain deployment of UserDeposit and constructor arguments at deployment time """
+    """Check an onchain deployment of UserDeposit and constructor arguments at deployment time"""
     if len(constructor_arguments) != 2:
         raise RuntimeError("UserDeposit has a wrong number of constructor arguments.")
     if token_address != constructor_arguments[0]:
@@ -330,7 +320,7 @@ def _verify_monitoring_service_deployment(
     user_deposit_address: HexAddress,
     token_network_registry_address: HexAddress,
 ) -> None:
-    """ Check an onchain deployment of MonitoringService and constructor arguments """
+    """Check an onchain deployment of MonitoringService and constructor arguments"""
     if len(constructor_arguments) != 4:
         raise RuntimeError("MonitoringService has a wrong number of constructor arguments.")
     if to_checksum_address(monitoring_service.functions.token().call()) != token_address:
@@ -372,7 +362,7 @@ def _verify_one_to_n_deployment(
     service_registry_address: HexAddress,
     chain_id: int,
 ) -> None:
-    """ Check an onchain deployment of OneToN and constructor arguments """
+    """Check an onchain deployment of OneToN and constructor arguments"""
     if to_checksum_address(one_to_n.functions.deposit_contract().call()) != user_deposit_address:
         raise RuntimeError("OneToN has a wrong UserDeposit address onchain.")
     if user_deposit_address != constructor_arguments[0]:
@@ -388,7 +378,7 @@ def _verify_one_to_n_deployment(
 def _verify_service_registry_deployment(
     service_registry: Contract, constructor_arguments: List, token_address: HexAddress
 ) -> None:
-    """ Check an onchain deployment of ServiceRegistry and constructor arguments """
+    """Check an onchain deployment of ServiceRegistry and constructor arguments"""
     if len(constructor_arguments) != 8:
         raise RuntimeError(
             "ServiceRegistry was deployed with a wrong number of constructor arguments"
