@@ -22,11 +22,11 @@ snapshot_before_token_network = None
 
 
 @pytest.fixture
-def get_token_network(deploy_tester_contract: Callable, token_network_libs: Dict) -> Callable:
+def get_token_network(deploy_tester_contract: Callable) -> Callable:
     """Deploy a token network as a separate contract (registry is not used)"""
 
     def get(**arguments: Dict) -> Contract:
-        return deploy_tester_contract(CONTRACT_TOKEN_NETWORK, token_network_libs, **arguments)
+        return deploy_tester_contract(CONTRACT_TOKEN_NETWORK, **arguments)
 
     return get
 
@@ -50,7 +50,7 @@ def register_token_network(web3: Web3, contracts_manager: ContractManager) -> Ca
             ),
             {"from": DEPLOYER_ADDRESS},
         )
-        tx_receipt = web3.eth.getTransactionReceipt(tx_hash)
+        tx_receipt = web3.eth.get_transaction_receipt(tx_hash)
         event_abi = contracts_manager.get_event_abi(
             CONTRACT_TOKEN_NETWORK_REGISTRY, EVENT_TOKEN_NETWORK_CREATED
         )
@@ -159,7 +159,7 @@ def token_network_external(
         _chain_id=web3.eth.chain_id,
         _settlement_timeout_min=TEST_SETTLE_TIMEOUT_MIN,
         _settlement_timeout_max=TEST_SETTLE_TIMEOUT_MAX,
-        _deprecation_executor=DEPLOYER_ADDRESS,
+        _controller=DEPLOYER_ADDRESS,
         _channel_participant_deposit_limit=channel_participant_deposit_limit,
         _token_network_deposit_limit=token_network_deposit_limit,
     )
