@@ -10,8 +10,6 @@ from raiden_contracts.constants import (
     CONTRACT_TOKEN_NETWORK,
     CONTRACT_TOKEN_NETWORK_REGISTRY,
     EVENT_TOKEN_NETWORK_CREATED,
-    LIBRARY_TOKEN_NETWORK_UTILS,
-    LIBRARY_TOKEN_NETWORK_UTILS_LINK_KEY,
     TEST_SETTLE_TIMEOUT_MAX,
     TEST_SETTLE_TIMEOUT_MIN,
 )
@@ -21,26 +19,10 @@ from raiden_contracts.tests.utils.constants import DEPLOYER_ADDRESS
 from raiden_contracts.utils.transaction import check_successful_tx
 
 
-@pytest.fixture(scope="session")
-def token_network_utils_library(deploy_tester_contract: Callable) -> Contract:
-    """Deployed TokenNetworkUtils library"""
-    return deploy_tester_contract(LIBRARY_TOKEN_NETWORK_UTILS)
-
-
-@pytest.fixture(scope="session")
-def token_network_libs(token_network_utils_library: Contract) -> Dict:
-    """Deployed TokenNetworkUtils library"""
-    return {LIBRARY_TOKEN_NETWORK_UTILS_LINK_KEY: token_network_utils_library.address}
-
-
 @pytest.fixture()
-def get_token_network_registry(
-    deploy_tester_contract: Callable, token_network_libs: Dict
-) -> Callable:
+def get_token_network_registry(deploy_tester_contract: Callable) -> Callable:
     def get(**arguments: Dict) -> Contract:
-        return deploy_tester_contract(
-            CONTRACT_TOKEN_NETWORK_REGISTRY, token_network_libs, **arguments
-        )
+        return deploy_tester_contract(CONTRACT_TOKEN_NETWORK_REGISTRY, **arguments)
 
     return get
 
@@ -62,12 +44,10 @@ def token_network_registry_constructor_args(
 def token_network_registry_contract(
     deploy_tester_contract: Callable,
     token_network_registry_constructor_args: Dict,
-    token_network_libs: Dict,
 ) -> Contract:
     """Deployed TokenNetworkRegistry contract"""
     return deploy_tester_contract(
         CONTRACT_TOKEN_NETWORK_REGISTRY,
-        token_network_libs,
         **token_network_registry_constructor_args,
     )
 
@@ -76,13 +56,11 @@ def token_network_registry_contract(
 def token_network_registry_contract2(
     deploy_tester_contract: Callable,
     token_network_registry_constructor_args: Dict,
-    token_network_libs: Dict,
 ) -> Contract:
     """Another deployed TokenNetworkRegistry contract to which service payment contracts
     should not collaborate."""
     return deploy_tester_contract(
         CONTRACT_TOKEN_NETWORK_REGISTRY,
-        token_network_libs,
         **token_network_registry_constructor_args,
     )
 
