@@ -32,7 +32,7 @@ from raiden_contracts.utils.pending_transfers import (
 
 
 def test_packed_transfer_0_items(token_network_test_utils: Contract) -> None:
-    """ getHashAndUnlockedAmount() returns a reasonable return value for no items """
+    """getHashAndUnlockedAmount() returns a reasonable return value for no items"""
     (
         locksroot,
         unlocked_amount,
@@ -42,7 +42,7 @@ def test_packed_transfer_0_items(token_network_test_utils: Contract) -> None:
 
 
 def test_0_item_unlockable(web3: Web3, token_network_test_utils: Contract) -> None:
-    """ Test getHashRootAndUnlockedAmount() on zero items whose secret has been registered """
+    """Test getHashRootAndUnlockedAmount() on zero items whose secret has been registered"""
     pending_transfers_tree = get_pending_transfers_tree(
         web3=web3, unlockable_amounts=[], expired_amounts=[]
     )
@@ -65,7 +65,7 @@ def test_1_item_unlockable(
     token_network_test_utils: Contract,
     secret_registry_contract: Contract,
 ) -> None:
-    """ Test getHashRootAndUnlockedAmount() on a single item whose secret has been registered """
+    """Test getHashRootAndUnlockedAmount() on a single item whose secret has been registered"""
     A = get_accounts(1)[0]
     pending_transfers_tree = get_pending_transfers_tree(
         web3=web3, unlockable_amounts=[6], expired_amounts=[]
@@ -102,7 +102,7 @@ def test_get_hash_length_fail(
     token_network_test_utils: Contract,
     secret_registry_contract: Contract,
 ) -> None:
-    """ Test getHashAndUnlockedAmount() on inputs of irregular lengths """
+    """Test getHashAndUnlockedAmount() on inputs of irregular lengths"""
     network_utils = token_network_test_utils
     A = get_accounts(1)[0]
     pending_transfers_tree = get_pending_transfers_tree(web3, [2, 3, 6], [5])
@@ -123,13 +123,13 @@ def test_get_hash_length_fail(
     packed = pending_transfers_tree.packed_transfers
 
     # packed length must be a multiple of 96
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: invalid locks size"):
         network_utils.functions.getHashAndUnlockedAmountPublic(packed[0:-1]).call()
     # last lock only contains expiration + locked_amount
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: invalid locks size"):
         network_utils.functions.getHashAndUnlockedAmountPublic(packed[0:-32]).call()
     # last lock only contains expiration
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: invalid locks size"):
         network_utils.functions.getHashAndUnlockedAmountPublic(packed[0:-64]).call()
 
     assert len(packed) % 96 == 0
@@ -143,7 +143,7 @@ def test_odd_even_components(
     token_network_test_utils: Contract,
     reveal_secrets: Callable,
 ) -> None:
-    """ Test getHashAndUnlockedAmount() on an odd/even number of locks """
+    """Test getHashAndUnlockedAmount() on an odd/even number of locks"""
     A = get_accounts(1)[0]
 
     # Even number of locks
@@ -185,7 +185,7 @@ def test_locks_order(
     token_network: Contract,
     create_settled_channel: Callable,
 ) -> None:
-    """ Shuffling the leaves usually changes the root, but sometimes not """
+    """Shuffling the leaves usually changes the root, but sometimes not"""
     network_utils = token_network_test_utils
     (A, B) = get_accounts(2)
     types = ["uint256", "uint256", "bytes32"]
@@ -214,7 +214,7 @@ def test_locks_order(
     # If we change the order, we change the computed hash.
     assert locksroot != pending_transfers_tree.hash_of_packed_transfers
     assert unlocked_amount == 9
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(channel_identifier, B, A, wrong_order_packed).call()
 
     wrong_order = pending_transfers_tree.transfers
@@ -226,7 +226,7 @@ def test_locks_order(
     ) = network_utils.functions.getHashAndUnlockedAmountPublic(wrong_order_packed).call()
     assert locksroot != pending_transfers_tree.hash_of_packed_transfers
     assert unlocked_amount == 9
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(channel_identifier, B, A, wrong_order_packed).call()
 
     wrong_order = pending_transfers_tree.transfers
@@ -238,7 +238,7 @@ def test_locks_order(
     ) = network_utils.functions.getHashAndUnlockedAmountPublic(wrong_order_packed).call()
     assert locksroot != pending_transfers_tree.hash_of_packed_transfers
     assert unlocked_amount == 9
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(channel_identifier, B, A, wrong_order_packed).call()
 
     (locksroot, unlocked_amount,) = network_utils.functions.getHashAndUnlockedAmountPublic(
@@ -260,7 +260,7 @@ def test_lock_data_from_packed_locks(
     secret_registry_contract: Contract,
     reveal_secrets: Callable,
 ) -> None:
-    """ Test getLockDataFromLockPublic() on various offsets """
+    """Test getLockDataFromLockPublic() on various offsets"""
     network_utils = token_network_test_utils
     A = get_accounts(1)[0]
 
@@ -330,7 +330,7 @@ def test_lock_data_from_packed_locks(
 def test_unlock_wrong_locksroot(
     web3: Web3, token_network: Contract, create_settled_channel: Callable, get_accounts: Callable
 ) -> None:
-    """ Test unlocking with wrong pending locks """
+    """Test unlocking with wrong pending locks"""
     (A, B) = get_accounts(2)
     settle_timeout = 8
 
@@ -347,13 +347,13 @@ def test_unlock_wrong_locksroot(
         settle_timeout,
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(
             channel_identifier, B, A, pending_transfers_tree_A_fake.packed_transfers
         ).call()
 
     # Fails for an empty packed locks
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(channel_identifier, B, A, b"").call()
 
     call_and_transact(
@@ -491,7 +491,7 @@ def test_channel_unlock_bigger_unlocked_amount(
     get_accounts: Callable,
     reveal_secrets: Callable,
 ) -> None:
-    """ unlock() transfers not more than the locked amount for more expensive unlock() demands """
+    """unlock() transfers not more than the locked amount for more expensive unlock() demands"""
     (A, B) = get_accounts(2)
     settle_timeout = 8
 
@@ -543,7 +543,7 @@ def test_channel_unlock_no_locked_amount_fail(
     get_accounts: Callable,
     reveal_secrets: Callable,
 ) -> None:
-    """ After settleChannel() is called with zero locked amount, unlock() calls fail """
+    """After settleChannel() is called with zero locked amount, unlock() calls fail"""
     (A, B) = get_accounts(2)
     settle_timeout = 8
 
@@ -555,9 +555,9 @@ def test_channel_unlock_no_locked_amount_fail(
         A, 0, LOCKSROOT_OF_NO_LOCKS, B, 0, LOCKSROOT_OF_NO_LOCKS, settle_timeout
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(channel_identifier, B, A, b"").call()
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(
             channel_identifier, B, A, pending_transfers_tree_A.packed_transfers
         ).call()
@@ -638,7 +638,7 @@ def test_channel_settle_and_unlock(
     create_settled_channel: Callable,
     reveal_secrets: Callable,
 ) -> None:
-    """ Regular channel life-cycle: open -> settle -> unlock -> open -> settle -> unlock """
+    """Regular channel life-cycle: open -> settle -> unlock -> open -> settle -> unlock"""
     (A, B) = get_accounts(2)
     settle_timeout = 8
 
@@ -743,7 +743,7 @@ def test_channel_unlock_registered_expired_lock_refunds(
     get_accounts: Callable,
     close_and_update_channel: Callable,
 ) -> None:
-    """ unlock() should refund tokens locked with secrets revealed after the expiration """
+    """unlock() should refund tokens locked with secrets revealed after the expiration"""
     (A, B) = get_accounts(2)
     max_lock_expiration = 3
     settle_timeout = 8
@@ -816,7 +816,7 @@ def test_channel_unlock_unregistered_locks(
     close_and_update_channel: Callable,
     custom_token: Contract,
 ) -> None:
-    """ unlock() should refund tokens locked by secrets not registered before settlement """
+    """unlock() should refund tokens locked by secrets not registered before settlement"""
     (A, B) = get_accounts(2)
     settle_timeout = TEST_SETTLE_TIMEOUT_MIN
 
@@ -869,7 +869,7 @@ def test_channel_unlock_before_settlement_fails(
     close_and_update_channel: Callable,
     reveal_secrets: Callable,
 ) -> None:
-    """ unlock() should not work before settlement """
+    """unlock() should not work before settlement"""
     (A, B) = get_accounts(2)
     settle_timeout = 8
 
@@ -890,7 +890,7 @@ def test_channel_unlock_before_settlement_fails(
     reveal_secrets(A, pending_transfers_tree.unlockable)
 
     # Unlock fails before channel is not settled
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: channel id still exists"):
         token_network.functions.unlock(
             channel_identifier, A, B, pending_transfers_tree.packed_transfers
         ).call()
@@ -899,7 +899,7 @@ def test_channel_unlock_before_settlement_fails(
     channel_deposit(channel_identifier, B, values_B.deposit, A)
 
     # Unlock fails before channel is not settled
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: channel id still exists"):
         token_network.functions.unlock(
             channel_identifier, A, B, pending_transfers_tree.packed_transfers
         ).call()
@@ -907,7 +907,7 @@ def test_channel_unlock_before_settlement_fails(
     close_and_update_channel(channel_identifier, A, values_A, B, values_B)
 
     # Unlock fails before settlement window is over and channel is not settled
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: channel id still exists"):
         token_network.functions.unlock(
             channel_identifier, A, B, pending_transfers_tree.packed_transfers
         ).call()
@@ -916,7 +916,7 @@ def test_channel_unlock_before_settlement_fails(
     mine_blocks(web3, settle_timeout)
 
     # Unlock fails before settle is called
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: channel id still exists"):
         token_network.functions.unlock(
             channel_identifier, A, B, pending_transfers_tree.packed_transfers
         ).call()
@@ -950,7 +950,7 @@ def test_unlock_fails_with_partial_locks(
     create_settled_channel: Callable,
     reveal_secrets: Callable,
 ) -> None:
-    """ unlock() should fail when one lock is missing """
+    """unlock() should fail when one lock is missing"""
     (A, B) = get_accounts(2)
     settle_timeout = 8
 
@@ -975,7 +975,7 @@ def test_unlock_fails_with_partial_locks(
         pending_transfers = list(pending_transfers_tree.transfers)
         del pending_transfers[index]
         packed_transfers_tampered = get_packed_transfers(tuple(pending_transfers), types)
-        with pytest.raises(TransactionFailed):
+        with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
             token_network.functions.unlock(
                 channel_identifier, B, A, packed_transfers_tampered
             ).call({"from": A})
@@ -996,7 +996,7 @@ def test_unlock_tampered_proof_fails(
     create_settled_channel: Callable,
     reveal_secrets: Callable,
 ) -> None:
-    """ unlock() should fail when the submitted proofs are tampered """
+    """unlock() should fail when the submitted proofs are tampered"""
     (A, B) = get_accounts(2)
     settle_timeout = 8
 
@@ -1021,7 +1021,7 @@ def test_unlock_tampered_proof_fails(
         pending_transfers = list(pending_transfers_tree.transfers)
         pending_transfers[index][2:] = random_secret()
         packed_transfers_tampered = get_packed_transfers(tuple(pending_transfers), types)
-        with pytest.raises(TransactionFailed):
+        with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
             token_network.functions.unlock(
                 channel_identifier, B, A, packed_transfers_tampered
             ).call({"from": A})
@@ -1046,7 +1046,7 @@ def test_channel_unlock_both_participants(
     close_and_update_channel: Callable,
     reveal_secrets: Callable,
 ) -> None:
-    """ A scenario where both parties get some of the pending transfers """
+    """A scenario where both parties get some of the pending transfers"""
     (A, B) = get_accounts(2)
     settle_timeout = 8
 
@@ -1138,7 +1138,7 @@ def test_unlock_twice_fails(
     create_settled_channel: Callable,
     reveal_secrets: Callable,
 ) -> None:
-    """ The same unlock() call twice do not work """
+    """The same unlock() call twice do not work"""
     (A, B) = get_accounts(2)
     settle_timeout = 8
 
@@ -1164,7 +1164,7 @@ def test_unlock_twice_fails(
     )
 
     # Calling unlock twice does not work
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(
             channel_identifier, B, A, pending_transfers_tree_1.packed_transfers
         ).call({"from": A})
@@ -1173,7 +1173,7 @@ def test_unlock_twice_fails(
 def test_unlock_no_locks(
     web3: Web3, token_network: Contract, get_accounts: Callable, create_settled_channel: Callable
 ) -> None:
-    """ unlock() should work on no pending locks """
+    """unlock() should work on no pending locks"""
     (A, B) = get_accounts(2)
     settle_timeout = 8
 
@@ -1203,7 +1203,7 @@ def test_unlock_no_locks(
     )
 
     # Calling unlock twice does not work
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(
             channel_identifier, B, A, pending_transfers_tree.packed_transfers
         ).call({"from": A})
@@ -1219,7 +1219,7 @@ def test_channel_unlock_with_a_large_expiration(
     close_and_update_channel: Callable,
     reveal_secrets: Callable,
 ) -> None:
-    """ unlock() should still work after a delayed settleChannel() call """
+    """unlock() should still work after a delayed settleChannel() call"""
     (A, B) = get_accounts(2)
     settle_timeout = 8
 
@@ -1276,7 +1276,7 @@ def test_reverse_participants_unlock(
     create_settled_channel: Callable,
     reveal_secrets: Callable,
 ) -> None:
-    """ unlock() with wrong argument orders """
+    """unlock() with wrong argument orders"""
     (A, B, C) = get_accounts(3)
     settle_timeout = 12
 
@@ -1304,35 +1304,35 @@ def test_reverse_participants_unlock(
     )
 
     # A trying to unlock its own locksroot & locked amount MUST fail
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(
             channel_identifier, A, B, pending_transfers_tree_A.packed_transfers
         ).call({"from": A})
 
     # Delegate trying to unlock A's own locksroot & locked amount on behalf of A MUST fail
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(
             channel_identifier, A, B, pending_transfers_tree_A.packed_transfers
         ).call({"from": C})
 
     # B trying to unlock its own locksroot & locked amount MUST fail
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(
             channel_identifier, B, A, pending_transfers_tree_B.packed_transfers
         ).call({"from": B})
 
     # Delegate trying to unlock B's own locksroot & locked amount on behalf of B MUST fail
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(
             channel_identifier, B, A, pending_transfers_tree_B.packed_transfers
         ).call({"from": B})
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: identical addresses"):
         token_network.functions.unlock(
             channel_identifier, A, A, pending_transfers_tree_A.packed_transfers
         ).call({"from": A})
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: identical addresses"):
         token_network.functions.unlock(
             channel_identifier, B, B, pending_transfers_tree_B.packed_transfers
         ).call({"from": B})
@@ -1361,7 +1361,7 @@ def test_unlock_different_channel_same_participants_fail(
     create_settled_channel: Callable,
     reveal_secrets: Callable,
 ) -> None:
-    """ Try to confuse unlock() with two channels between the same participants """
+    """Try to confuse unlock() with two channels between the same participants"""
     (A, B) = get_accounts(2)
     settle_timeout = 8
 
@@ -1391,11 +1391,11 @@ def test_unlock_different_channel_same_participants_fail(
         settle_timeout,
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(
             channel_identifier, B, A, pending_transfers_tree_2.packed_transfers
         ).call({"from": A})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/unlock: locksroot mismatch"):
         token_network.functions.unlock(
             channel_identifier2, B, A, pending_transfers_tree_1.packed_transfers
         ).call({"from": A})
@@ -1425,7 +1425,7 @@ def test_unlock_channel_event(
     reveal_secrets: Callable,
     event_handler: Callable,
 ) -> None:
-    """ Successful unlock() should cause an UNLOCKED event """
+    """Successful unlock() should cause an UNLOCKED event"""
     (A, B) = get_accounts(2)
     settle_timeout = 8
 
