@@ -14,6 +14,7 @@ from raiden_contracts.constants import (
     ParticipantInfoIndex,
 )
 from raiden_contracts.tests.utils import call_and_transact
+from raiden_contracts.tests.utils.constants import DEPLOYER_ADDRESS, UINT256_MAX
 
 
 def test_register_three_but_not_four(
@@ -24,7 +25,7 @@ def test_register_three_but_not_four(
     channel_participant_deposit_limit: int,
     token_network_deposit_limit: int,
 ) -> None:
-    """ Check that TokenNetworkRegistry observes the max number of tokens """
+    """Check that TokenNetworkRegistry observes the max number of tokens"""
     token_network_registry = get_token_network_registry(
         _secret_registry_address=secret_registry_contract.address,
         _chain_id=web3.eth.chain_id,
@@ -37,6 +38,7 @@ def test_register_three_but_not_four(
     token1 = custom_token_factory()
     token2 = custom_token_factory()
     token3 = custom_token_factory()
+    token4 = custom_token_factory()
     call_and_transact(
         token_network_registry.functions.createERC20TokenNetwork(
             token0.address,
@@ -44,6 +46,15 @@ def test_register_three_but_not_four(
             token_network_deposit_limit,
         )
     )
+    # Registering the same token again must fail
+    with pytest.raises(TransactionFailed, match="TNR: token already registered"):
+        call_and_transact(
+            token_network_registry.functions.createERC20TokenNetwork(
+                token0.address,
+                channel_participant_deposit_limit,
+                token_network_deposit_limit,
+            )
+        )
     call_and_transact(
         token_network_registry.functions.createERC20TokenNetwork(
             token1.address,
@@ -58,22 +69,40 @@ def test_register_three_but_not_four(
             token_network_deposit_limit,
         )
     )
-    with pytest.raises(TransactionFailed, match="registry full"):
+    with pytest.raises(TransactionFailed, match="TNR: registry full"):
         token_network_registry.functions.createERC20TokenNetwork(
             token3.address,
             channel_participant_deposit_limit,
             token_network_deposit_limit,
         ).call()
 
+    # Now remove the limit and try again
+    call_and_transact(token_network_registry.functions.removeLimits(), {"from": DEPLOYER_ADDRESS})
+    with pytest.raises(TransactionFailed, match="TNR: limits must be set to MAX_INT"):
+        call_and_transact(
+            token_network_registry.functions.createERC20TokenNetwork(
+                token4.address,
+                channel_participant_deposit_limit,
+                token_network_deposit_limit,
+            )
+        )
+    call_and_transact(
+        token_network_registry.functions.createERC20TokenNetwork(
+            token4.address,
+            UINT256_MAX,
+            UINT256_MAX,
+        )
+    )
+
 
 def test_channel_participant_deposit_limit_value(token_network: Contract) -> None:
-    """ Check the channel participant deposit limit """
+    """Check the channel participant deposit limit"""
     limit = token_network.functions.channel_participant_deposit_limit().call()
     assert limit == MAX_ETH_CHANNEL_PARTICIPANT
 
 
 def test_network_deposit_limit_value(token_network: Contract) -> None:
-    """ Check the token network deposit limit """
+    """Check the token network deposit limit"""
     limit = token_network.functions.token_network_deposit_limit().call()
     assert limit == MAX_ETH_TOKEN_NETWORK
 
@@ -84,7 +113,7 @@ def test_participant_deposit_limit(
     create_channel: Callable,
     assign_tokens: Callable,
 ) -> None:
-    """ Observe failure to deposit a bit more tokens than the participant deposit limit """
+    """Observe failure to deposit a bit more tokens than the participant deposit limit"""
     (A, B) = get_accounts(2)
     deposit_A = 100000
     deposit_B = 100000
@@ -92,11 +121,11 @@ def test_participant_deposit_limit(
     assign_tokens(A, MAX_ETH_CHANNEL_PARTICIPANT + 10)
     assign_tokens(B, MAX_ETH_CHANNEL_PARTICIPANT + 10)
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/deposit: deposit limit reached"):
         token_network.functions.setTotalDeposit(
             channel_identifier, A, MAX_ETH_CHANNEL_PARTICIPANT + 1, B
         ).call({"from": A})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/deposit: deposit limit reached"):
         token_network.functions.setTotalDeposit(
             channel_identifier, B, MAX_ETH_CHANNEL_PARTICIPANT + 1, A
         ).call({"from": B})
@@ -109,18 +138,18 @@ def test_participant_deposit_limit(
     info_A = token_network.functions.getChannelParticipantInfo(channel_identifier, A, B).call()
     assert info_A[ParticipantInfoIndex.DEPOSIT] == deposit_A
 
-    info_B = call_and_transact(
+    call_and_transact(
         token_network.functions.setTotalDeposit(channel_identifier, B, deposit_B, A),
         {"from": B},
     )
     info_B = token_network.functions.getChannelParticipantInfo(channel_identifier, B, A).call()
     assert info_B[ParticipantInfoIndex.DEPOSIT] == deposit_B
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/deposit: deposit limit reached"):
         token_network.functions.setTotalDeposit(
             channel_identifier, A, MAX_ETH_CHANNEL_PARTICIPANT + 1, B
         ).call({"from": A})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/deposit: deposit limit reached"):
         token_network.functions.setTotalDeposit(
             channel_identifier, B, MAX_ETH_CHANNEL_PARTICIPANT + 1, A
         ).call({"from": B})
@@ -138,6 +167,14 @@ def test_participant_deposit_limit(
         {"from": B},
     )
 
+    # Now disable the limits and try again
+    with pytest.raises(TransactionFailed, match="Can only be called by"):
+        call_and_transact(token_network.functions.removeLimits())
+    call_and_transact(token_network.functions.removeLimits(), {"from": DEPLOYER_ADDRESS})
+    token_network.functions.setTotalDeposit(
+        channel_identifier, B, MAX_ETH_CHANNEL_PARTICIPANT + 1, A
+    ).call({"from": B})
+
 
 @pytest.mark.skip(reason="Only for local testing, otherwise it takes too much time to run.")
 def test_network_deposit_limit(
@@ -221,11 +258,15 @@ def test_network_deposit_limit(
     )
 
     # After token network limit is reached, we cannot deposit anymore tokens in existent channels
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="abc"):
         token_network.functions.setTotalDeposit(channel_identifier, A, 1, B).call({"from": A})
 
     # After token network limit is reached, we cannot open new channels
     C = create_account()
     D = create_account()
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="abc"):
         create_channel(C, D)
+
+    # Now disable the limits and try again
+    call_and_transact(token_network.functions.removeLimits(), {"from": DEPLOYER_ADDRESS})
+    token_network.functions.setTotalDeposit(channel_identifier, A, 1, B).call({"from": A})
