@@ -1,4 +1,4 @@
-from typing import Callable, Dict
+from typing import Callable
 
 import pytest
 from eth_tester.exceptions import TransactionFailed
@@ -22,11 +22,10 @@ from raiden_contracts.utils.pending_transfers import (
 )
 
 
-def test_deprecation_executor(
+def test_controller(
     web3: Web3,
     contracts_manager: ContractManager,
     deploy_tester_contract: Callable,
-    token_network_libs: Dict,
     secret_registry_contract: Contract,
     custom_token: Contract,
     channel_participant_deposit_limit: int,
@@ -41,12 +40,11 @@ def test_deprecation_executor(
     original account as the deprecation executor. During these, this test also
     tries to register more than one TokenNetworks and see a failure.
     """
-    (deprecation_executor, B) = get_accounts(2)
+    (controller, B) = get_accounts(2)
 
     token_network_registry = deploy_tester_contract(
         CONTRACT_TOKEN_NETWORK_REGISTRY,
-        token_network_libs,
-        deprecation_executor,
+        controller,
         _secret_registry_address=secret_registry_contract.address,
         _chain_id=web3.eth.chain_id,
         _settlement_timeout_min=TEST_SETTLE_TIMEOUT_MIN,
@@ -54,8 +52,8 @@ def test_deprecation_executor(
         _max_token_networks=1,
     )
 
-    # Make sure deployer is deprecation_executor
-    assert token_network_registry.functions.deprecation_executor().call() == deprecation_executor
+    # Make sure deployer is controller
+    assert token_network_registry.functions.controller().call() == controller
     assert token_network_registry.functions.token_network_created().call() == 0
 
     # We can only deploy one TokenNetwork contract
@@ -71,20 +69,20 @@ def test_deprecation_executor(
     assert token_network_registry.functions.token_network_created().call() == 1
 
     # No other TokenNetworks can be deployed now
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TNR: registry full"):
         token_network_registry.functions.createERC20TokenNetwork(
             custom_token.address,
             channel_participant_deposit_limit,
             token_network_deposit_limit,
         ).call({"from": B})
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TNR: registry full"):
         token_network_registry.functions.createERC20TokenNetwork(
             custom_token.address,
             channel_participant_deposit_limit,
             token_network_deposit_limit,
-        ).call({"from": deprecation_executor})
+        ).call({"from": controller})
 
-    tx_receipt = web3.eth.getTransactionReceipt(tx_hash)
+    tx_receipt = web3.eth.get_transaction_receipt(tx_hash)
     event_abi = contracts_manager.get_event_abi(
         CONTRACT_TOKEN_NETWORK_REGISTRY, EVENT_TOKEN_NETWORK_CREATED
     )
@@ -95,7 +93,7 @@ def test_deprecation_executor(
         address=token_network_address,
     )
 
-    assert token_network.functions.deprecation_executor().call() == deprecation_executor
+    assert token_network.functions.controller().call() == controller
 
 
 def test_set_deprecation_switch(
@@ -104,24 +102,24 @@ def test_set_deprecation_switch(
     web3: Web3,
     contracts_manager: ContractManager,
 ) -> None:
-    """ The deprecation executor deprecates a TokenNetwork contract """
+    """The deprecation executor deprecates a TokenNetwork contract"""
     (A) = get_accounts(1)[0]
-    deprecation_executor = token_network.functions.deprecation_executor().call()
+    controller = token_network.functions.controller().call()
 
     assert token_network.functions.safety_deprecation_switch().call() is False
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="Can only be called by controller"):
         token_network.functions.deprecate().call({"from": A})
 
-    tx = call_and_transact(token_network.functions.deprecate(), {"from": deprecation_executor})
+    tx = call_and_transact(token_network.functions.deprecate(), {"from": controller})
     assert token_network.functions.safety_deprecation_switch().call() is True
-    tx_receipt = web3.eth.getTransactionReceipt(tx)
+    tx_receipt = web3.eth.get_transaction_receipt(tx)
     event_abi = contracts_manager.get_event_abi(CONTRACT_TOKEN_NETWORK, EVENT_DEPRECATION_SWITCH)
     event_data = get_event_data(web3.codec, event_abi, tx_receipt["logs"][0])
     assert event_data["args"]["new_value"]
 
     # We should not be able to call it again
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: network is deprecated"):
         token_network.functions.deprecate().call({"from": A})
 
 
@@ -131,9 +129,9 @@ def test_deprecation_switch(
     create_channel: Callable,
     channel_deposit: Callable,
 ) -> None:
-    """ Test the effects of the deprecation switch on deposits and channel opening """
+    """Test the effects of the deprecation switch on deposits and channel opening"""
 
-    deprecation_executor = token_network.functions.deprecation_executor().call()
+    controller = token_network.functions.controller().call()
     (A, B, C, D) = get_accounts(4)
     deposit = 100
     bigger_deposit = 200
@@ -142,17 +140,17 @@ def test_deprecation_switch(
     channel_deposit(channel_identifier, A, deposit, B)
     channel_deposit(channel_identifier, B, deposit, A)
 
-    call_and_transact(token_network.functions.deprecate(), {"from": deprecation_executor})
+    call_and_transact(token_network.functions.deprecate(), {"from": controller})
     assert token_network.functions.safety_deprecation_switch().call() is True
 
     # Now we cannot deposit in existent channels
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: network is deprecated"):
         channel_deposit(channel_identifier, A, bigger_deposit, B)
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: network is deprecated"):
         channel_deposit(channel_identifier, B, bigger_deposit, A)
 
     # Now we cannot open channels anymore
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: network is deprecated"):
         channel_identifier = create_channel(C, D)[0]
 
 
@@ -166,8 +164,8 @@ def test_deprecation_switch_settle(
     channel_deposit: Callable,
     close_and_update_channel: Callable,
 ) -> None:
-    """ Channel close and settlement still work after the depracation switch is turned on """
-    deprecation_executor = token_network.functions.deprecation_executor().call()
+    """Channel close and settlement still work after the depracation switch is turned on"""
+    controller = token_network.functions.controller().call()
     (A, B) = get_accounts(2)
     deposit = 100
 
@@ -215,7 +213,7 @@ def test_deprecation_switch_settle(
     reveal_secrets(B, pending_transfers_tree_B.unlockable)
 
     # Set the deprecation switch to true
-    call_and_transact(token_network.functions.deprecate(), {"from": deprecation_executor})
+    call_and_transact(token_network.functions.deprecate(), {"from": controller})
     assert token_network.functions.safety_deprecation_switch().call() is True
 
     # We need to make sure we can still close, settle & unlock the channels
