@@ -231,25 +231,28 @@ def test_monitor(
 ) -> None:
     A, B = monitor_data["participants"]
 
-    # UpdateNonClosingBalanceProof is tested speparately, so we assume that all
+    # UpdateNonClosingBalanceProof is tested separately, so we assume that all
     # parameters passed to it are handled correctly.
 
-    # changing reward amount must lead to a failure during reward signature check
+    # Changing reward amount must lead to a failure during reward signature check.
     with pytest.raises(TransactionFailed, match="Reward proof with wrong non_closing_participant"):
-        txn_hash = monitoring_service_external.functions.monitor(
-            A,
-            B,
-            *monitor_data["balance_proof_B"]._asdict().values(),
-            monitor_data["non_closing_signature"],
-            REWARD_AMOUNT + 1,
-            token_network.address,
-            monitor_data["reward_proof_signature"],
-        ).call({"from": ms_address})
+        call_and_transact(
+            monitoring_service_external.functions.monitor(
+                A,
+                B,
+                *monitor_data["balance_proof_B"]._asdict().values(),
+                monitor_data["non_closing_signature"],
+                REWARD_AMOUNT + 1,
+                token_network.address,
+                monitor_data["reward_proof_signature"],
+            ),
+            {"from": ms_address},
+        )
 
     # monitoring too early must fail
     with pytest.raises(TransactionFailed, match="not allowed to monitor"):
         assert web3.eth.block_number < monitor_data["first_allowed"]
-        txn_hash = call_and_transact(
+        call_and_transact(
             monitoring_service_external.functions.monitor(
                 A,
                 B,
