@@ -12,7 +12,6 @@ from raiden_contracts.constants import (
     CONTRACT_TOKEN_NETWORK,
     CONTRACT_TOKEN_NETWORK_REGISTRY,
     CONTRACT_USER_DEPOSIT,
-    LIBRARY_TOKEN_NETWORK_UTILS,
     TEST_SETTLE_TIMEOUT_MAX,
     TEST_SETTLE_TIMEOUT_MIN,
     MessageTypeId,
@@ -28,10 +27,9 @@ from raiden_contracts.utils.type_aliases import BlockExpiration, ChainID, TokenA
 
 @pytest.mark.parametrize("version", [None])
 def test_gas_json_has_enough_fields(version: Optional[str]) -> None:
-    """ Check is gas.json contains enough fields """
+    """Check is gas.json contains enough fields"""
     doc = gas_measurements(version)
     keys = {
-        "TokenNetworkUtils DEPLOYMENT",
         "CustomToken.mint",
         "CustomToken.approve",
         "CustomToken.transfer",
@@ -49,7 +47,9 @@ def test_gas_json_has_enough_fields(version: Optional[str]) -> None:
         "ServiceRegistry.setURL",
         "TokenNetwork DEPLOYMENT",
         "TokenNetwork.closeChannel",
+        "TokenNetwork.cooperativeSettle",
         "TokenNetwork.openChannel",
+        "TokenNetwork.openChannelWithDeposit",
         "TokenNetwork.setTotalDeposit",
         "TokenNetwork.setTotalWithdraw",
         "TokenNetwork.settleChannel",
@@ -66,28 +66,16 @@ def test_gas_json_has_enough_fields(version: Optional[str]) -> None:
     assert set(doc.keys()) == keys
 
 
-@pytest.fixture
-def print_gas_token_network_utils(
-    deploy_tester_contract_txhash: Callable,
-    print_gas: Callable,
-) -> None:
-    """ Abusing pytest to print the deployment gas cost of TokenNetworkUtils """
-    txhash = deploy_tester_contract_txhash(LIBRARY_TOKEN_NETWORK_UTILS)
-    print_gas(txhash, LIBRARY_TOKEN_NETWORK_UTILS + " DEPLOYMENT")
-
-
 @pytest.fixture
 def print_gas_token_network_registry(
     web3: Web3,
     deploy_tester_contract_txhash: Callable,
     secret_registry_contract: Contract,
-    token_network_libs: Dict,
     print_gas: Callable,
 ) -> None:
-    """ Abusing pytest to print the deployment gas cost of TokenNetworkRegistry """
+    """Abusing pytest to print the deployment gas cost of TokenNetworkRegistry"""
     txhash = deploy_tester_contract_txhash(
         CONTRACT_TOKEN_NETWORK_REGISTRY,
-        libs=token_network_libs,
         _secret_registry_address=secret_registry_contract.address,
         _chain_id=web3.eth.chain_id,
         _settlement_timeout_min=TEST_SETTLE_TIMEOUT_MIN,
@@ -103,23 +91,21 @@ def print_gas_token_network_deployment(
     get_accounts: Callable,
     print_gas: Callable,
     custom_token: Contract,
-    token_network_libs: Dict,
     secret_registry_contract: Contract,
     deploy_tester_contract_txhash: Callable,
     channel_participant_deposit_limit: int,
     token_network_deposit_limit: int,
 ) -> None:
-    """ Abusing pytest to print the deployment gas cost of TokenNetwork """
-    deprecation_executor = get_accounts(1)[0]
+    """Abusing pytest to print the deployment gas cost of TokenNetwork"""
+    controller = get_accounts(1)[0]
     txhash = deploy_tester_contract_txhash(
         CONTRACT_TOKEN_NETWORK,
-        libs=token_network_libs,
         _token_address=custom_token.address,
         _secret_registry=secret_registry_contract.address,
         _chain_id=web3.eth.chain_id,
         _settlement_timeout_min=TEST_SETTLE_TIMEOUT_MIN,
         _settlement_timeout_max=TEST_SETTLE_TIMEOUT_MAX,
-        _deprecation_executor=deprecation_executor,
+        _controller=controller,
         _channel_participant_deposit_limit=channel_participant_deposit_limit,
         _token_network_deposit_limit=token_network_deposit_limit,
     )
@@ -135,7 +121,7 @@ def print_gas_token_network_create(
     token_network_deposit_limit: int,
     token_network_registry_constructor_args: Dict,
 ) -> None:
-    """ Abusing pytest to print gas cost of TokenNetworkRegistry's createERC20TokenNetwork() """
+    """Abusing pytest to print gas cost of TokenNetworkRegistry's createERC20TokenNetwork()"""
     registry = get_token_network_registry(**token_network_registry_constructor_args)
     txn_hash = call_and_transact(
         registry.functions.createERC20TokenNetwork(
@@ -151,7 +137,7 @@ def print_gas_token_network_create(
 
 @pytest.fixture
 def print_gas_secret_registry(secret_registry_contract: Contract, print_gas: Callable) -> None:
-    """ Abusing pytest to print gas cost of SecretRegistry's registerSecret() """
+    """Abusing pytest to print gas cost of SecretRegistry's registerSecret()"""
     secret = b"secretsecretsecretsecretsecretse"
     txn_hash = call_and_transact(secret_registry_contract.functions.registerSecret(secret))
     print_gas(txn_hash, CONTRACT_SECRET_REGISTRY + ".registerSecret")
@@ -175,7 +161,7 @@ def print_gas_channel_cycle(
     create_balance_proof: Callable,
     create_balance_proof_countersignature: Callable,
 ) -> None:
-    """ Abusing pytest to print gas costs of TokenNetwork's operations """
+    """Abusing pytest to print gas costs of TokenNetwork's operations"""
     (A, B, C, D) = get_accounts(4)
     settle_timeout = 11
 
@@ -292,6 +278,45 @@ def print_gas_channel_cycle(
     )
 
 
+@pytest.fixture
+def print_gas_channel_open_with_deposit(
+    token_network: Contract,
+    get_accounts: Callable,
+    print_gas: Callable,
+    assign_tokens: Callable,
+) -> None:
+    """Abusing pytest to print gas costs of TokenNetwork's `openChannelWithDeposit`"""
+    (A, B) = get_accounts(2)
+    settle_timeout = 11
+    deposit = 20
+
+    assign_tokens(A, deposit)
+    tx_hash = call_and_transact(
+        token_network.functions.openChannelWithDeposit(A, B, settle_timeout, deposit),
+        {"from": A},
+    )
+    print_gas(tx_hash, CONTRACT_TOKEN_NETWORK + ".openChannelWithDeposit")
+
+
+@pytest.fixture
+def print_gas_coop_settle(
+    create_channel: Callable,
+    channel_deposit: Callable,
+    cooperative_settle_channel: Callable,
+    get_accounts: Callable,
+    print_gas: Callable,
+) -> None:
+    """Abusing pytest to print gas costs of cooperative settle"""
+    (A, B) = get_accounts(2)
+    settle_timeout = 11
+
+    (channel_identifier, txn_hash) = create_channel(A, B, settle_timeout)
+    channel_deposit(channel_identifier, A, 20, B)
+
+    txn_hash = cooperative_settle_channel(channel_identifier, A, B, 10, 10, UINT256_MAX, A)
+    print_gas(txn_hash, CONTRACT_TOKEN_NETWORK + ".cooperativeSettle")
+
+
 @pytest.fixture
 def print_gas_monitoring_service(
     token_network: Contract,
@@ -308,7 +333,7 @@ def print_gas_monitoring_service(
     create_service_account: Callable,
     web3: Web3,
 ) -> None:
-    """ Abusing pytest to print gas cost of MonitoringService functions """
+    """Abusing pytest to print gas cost of MonitoringService functions"""
     # setup: two parties + MS
     (A, MS) = get_accounts(2)
     B = create_service_account()
@@ -401,7 +426,7 @@ def print_gas_one_to_n(
     create_service_account: Callable,
     create_account: Callable,
 ) -> None:
-    """ Abusing pytest to print gas cost of OneToN functions """
+    """Abusing pytest to print gas cost of OneToN functions"""
     A = create_account()
     B = create_service_account()
     deposit_to_udc(A, 30)
@@ -420,9 +445,7 @@ def print_gas_one_to_n(
         chain_id=ChainID(chain_id),
     )
     txn_hash = call_and_transact(
-        one_to_n_contract.functions.claim(
-            A, B, amount, expiration, one_to_n_contract.address, signature
-        ),
+        one_to_n_contract.functions.claim(A, B, amount, expiration, signature),
         {"from": A},
     )
 
@@ -449,7 +472,6 @@ def print_gas_one_to_n(
                 concat_iou_data(ious, "receiver"),
                 concat_iou_data(ious, "amount"),
                 concat_iou_data(ious, "expiration_block"),
-                one_to_n_contract.address,
                 concat_iou_signatures(ious),
             ),
             {"from": A},
@@ -530,12 +552,13 @@ def print_gas_token(get_accounts: Callable, custom_token: Contract, print_gas: C
 # execution of multiple gas printing tests, you see a corrupted gas.json.
 @pytest.mark.slow
 @pytest.mark.usefixtures(
-    "print_gas_token_network_utils",
     "print_gas_token_network_registry",
     "print_gas_token_network_deployment",
     "print_gas_token_network_create",
     "print_gas_secret_registry",
     "print_gas_channel_cycle",
+    "print_gas_channel_open_with_deposit",
+    "print_gas_coop_settle",
     "print_gas_monitoring_service",
     "print_gas_one_to_n",
     "print_gas_service_registry",
