@@ -47,7 +47,7 @@ def test_deposit_contract(
 def test_deposit_contract_without_service_registry_code(
     get_deposit_contract: Callable, custom_token: Contract, get_accounts: Callable
 ) -> None:
-    """ If Deposit has no code in service registry, too early withdrawals fail """
+    """If Deposit has no code in service registry, too early withdrawals fail"""
     (A,) = get_accounts(1)
     call_and_transact(custom_token.functions.mint(100), {"from": A})
     depo = get_deposit_contract(
@@ -150,7 +150,7 @@ def test_setURL(
         {"from": A},
     )
     tx = call_and_transact(service_registry.functions.deposit(SERVICE_DEPOSIT), {"from": A})
-    tx_receipt = web3.eth.getTransactionReceipt(tx)
+    tx_receipt = web3.eth.get_transaction_receipt(tx)
     contract_manager = ContractManager(contracts_precompiled_path(version=None))
     event_abi = contract_manager.get_event_abi(CONTRACT_SERVICE_REGISTRY, EVENT_REGISTERED_SERVICE)
     event_data = get_event_data(web3.codec, event_abi, tx_receipt["logs"][-1])
@@ -447,7 +447,7 @@ def test_internal_min_price(service_registry: Contract) -> None:
 def test_unauthorized_parameter_change(service_registry: Contract, get_accounts: Callable) -> None:
     """A random address's changeParameters() call should fail"""
     (A,) = get_accounts(1)
-    with pytest.raises(TransactionFailed, match="caller is not the controller"):
+    with pytest.raises(TransactionFailed, match="Can only be called by controller"):
         call_and_transact(
             service_registry.functions.changeParameters(
                 _price_bump_numerator=DEFAULT_BUMP_NUMERATOR,
@@ -463,7 +463,7 @@ def test_unauthorized_parameter_change(service_registry: Contract, get_accounts:
 
 def test_parameter_change_on_no_controller(service_registry_without_controller: Contract) -> None:
     """A random address's changeParameters() call should fail"""
-    with pytest.raises(TransactionFailed, match="caller is not the controller"):
+    with pytest.raises(TransactionFailed, match="Can only be called by controller"):
         call_and_transact(
             service_registry_without_controller.functions.changeParameters(
                 _price_bump_numerator=DEFAULT_BUMP_NUMERATOR,
@@ -543,7 +543,7 @@ def test_deprecation_switch(
 def test_deprecation_immediate_payout(
     create_account: Callable, custom_token: Contract, service_registry: Contract, web3: Web3
 ) -> None:
-    """ When the deprecation switch is on, deposits can be withdrawn immediately. """
+    """When the deprecation switch is on, deposits can be withdrawn immediately."""
     # A user makes a deposit
     A = create_account()
     minted = service_registry.functions.currentPrice().call()
@@ -553,7 +553,7 @@ def test_deprecation_immediate_payout(
     )
     deposit_tx = call_and_transact(service_registry.functions.deposit(minted), {"from": A})
     # The user obtains the deposit address
-    deposit_tx_receipt = web3.eth.getTransactionReceipt(deposit_tx)
+    deposit_tx_receipt = web3.eth.get_transaction_receipt(deposit_tx)
     contract_manager = ContractManager(contracts_precompiled_path(version=None))
     event_abi = contract_manager.get_event_abi(CONTRACT_SERVICE_REGISTRY, EVENT_REGISTERED_SERVICE)
     event_data = get_event_data(web3.codec, event_abi, deposit_tx_receipt["logs"][-1])
@@ -578,7 +578,7 @@ def test_unauthorized_deprecation_switch(
 ) -> None:
     """A random account cannot turn on the deprecation switch"""
     (A,) = get_accounts(1)
-    with pytest.raises(TransactionFailed, match="caller is not the controller"):
+    with pytest.raises(TransactionFailed, match="Can only be called by controller"):
         call_and_transact(service_registry.functions.setDeprecationSwitch(), {"from": A})
 
 
@@ -588,7 +588,7 @@ def test_deploying_service_registry_with_denominator_zero(
     """ServiceRegistry's constructor must fail when denominator is zero"""
     # Web3 does not expose the error message "divide by zero"
     # when require() fails in the constructor.
-    with pytest.raises(TransactionFailed, match="deployment failed"):
+    with pytest.raises(TransactionFailed, match="divide by zero"):
         deploy_tester_contract(
             CONTRACT_SERVICE_REGISTRY,
             _token_for_registration=custom_token.address,
