@@ -24,7 +24,7 @@ def test_constructor_call(
     secret_registry_contract: Contract,
     get_accounts: Callable,
 ) -> None:
-    """ Try to create a TokenNetworkRegistry with various wrong arguments. """
+    """Try to create a TokenNetworkRegistry with various wrong arguments."""
     A = get_accounts(1)[0]
     chain_id = web3.eth.chain_id
     settle_min = TEST_SETTLE_TIMEOUT_MIN
@@ -105,7 +105,7 @@ def test_constructor_call(
         )
 
     # failure with chain ID zero
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TNR: invalid chain id"):
         get_token_network_registry(
             _secret_registry_address=secret_registry_contract.address,
             _chain_id=0,
@@ -154,7 +154,7 @@ def test_constructor_call(
         )
 
     # failure with Ethereum accounts that doesn't look like a SecretRegistry
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TNR: invalid SR address"):
         get_token_network_registry(
             _secret_registry_address=EMPTY_ADDRESS,
             _chain_id=chain_id,
@@ -162,7 +162,7 @@ def test_constructor_call(
             _settlement_timeout_max=settle_max,
             _max_token_networks=1,
         )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TNR: invalid SR"):
         get_token_network_registry(
             _secret_registry_address=A,
             _chain_id=chain_id,
@@ -172,7 +172,7 @@ def test_constructor_call(
         )
 
     # failures with chain_id zero
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TNR: invalid chain id"):
         get_token_network_registry(
             _secret_registry_address=secret_registry_contract.address,
             _chain_id=0,
@@ -180,7 +180,7 @@ def test_constructor_call(
             _settlement_timeout_max=settle_max,
             _max_token_networks=1,
         )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TNR: invalid chain id"):
         get_token_network_registry(
             _secret_registry_address=secret_registry_contract.address,
             _chain_id=0,
@@ -188,7 +188,7 @@ def test_constructor_call(
             _settlement_timeout_max=0,
             _max_token_networks=1,
         )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TNR: invalid chain id"):
         get_token_network_registry(
             _secret_registry_address=secret_registry_contract.address,
             _chain_id=0,
@@ -198,7 +198,7 @@ def test_constructor_call(
         )
 
     # failures with nonsense challenge periods
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TNR: invalid settle timeout min"):
         get_token_network_registry(
             _secret_registry_address=secret_registry_contract.address,
             _chain_id=chain_id,
@@ -206,7 +206,7 @@ def test_constructor_call(
             _settlement_timeout_max=settle_max,
             _max_token_networks=1,
         )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TNR: invalid settle timeout max"):
         get_token_network_registry(
             _secret_registry_address=secret_registry_contract.address,
             _chain_id=chain_id,
@@ -214,7 +214,7 @@ def test_constructor_call(
             _settlement_timeout_max=0,
             _max_token_networks=1,
         )
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TNR: invalid settle timeouts"):
         get_token_network_registry(
             _secret_registry_address=secret_registry_contract.address,
             _chain_id=chain_id,
@@ -224,11 +224,11 @@ def test_constructor_call(
         )
 
     # failures with nonsense token number limits
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TNR: invalid TN limit"):
         get_token_network_registry(
             _secret_registry_address=secret_registry_contract.address,
             _chain_id=chain_id,
-            _settlement_timeout_min=0,
+            _settlement_timeout_min=settle_min,
             _settlement_timeout_max=settle_max,
             _max_token_networks=0,
         )
@@ -254,7 +254,7 @@ def test_constructor_call(
 def test_constructor_call_state(
     web3: Web3, get_token_network_registry: Callable, secret_registry_contract: Contract
 ) -> None:
-    """ The constructor should set the parameters into the storage of the contract """
+    """The constructor should set the parameters into the storage of the contract"""
 
     chain_id = web3.eth.chain_id
 
@@ -280,7 +280,7 @@ def test_create_erc20_token_network_call(
     channel_participant_deposit_limit: int,
     token_network_deposit_limit: int,
 ) -> None:
-    """ Calling createERC20TokenNetwork() with various wrong arguments """
+    """Calling createERC20TokenNetwork() with various wrong arguments"""
 
     A = get_accounts(1)[0]
     fake_token_contract = token_network_registry_contract.address
@@ -310,13 +310,13 @@ def test_create_erc20_token_network_call(
         )
 
     # failures with addresses where no Token contract can be found
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: invalid token address"):
         token_network_registry_contract.functions.createERC20TokenNetwork(
             EMPTY_ADDRESS,
             channel_participant_deposit_limit,
             token_network_deposit_limit,
         ).call()
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: invalid token contract"):
         token_network_registry_contract.functions.createERC20TokenNetwork(
             A, channel_participant_deposit_limit, token_network_deposit_limit
         ).call()
@@ -328,17 +328,17 @@ def test_create_erc20_token_network_call(
         ).call()
 
     # failures with invalid deposit limits
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: invalid participant limit"):
         token_network_registry_contract.functions.createERC20TokenNetwork(
             custom_token.address, 0, token_network_deposit_limit
         ).call({"from": DEPLOYER_ADDRESS})
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: invalid network deposit limit"):
         token_network_registry_contract.functions.createERC20TokenNetwork(
             custom_token.address, channel_participant_deposit_limit, 0
         ).call({"from": DEPLOYER_ADDRESS})
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN: invalid deposit limits"):
         # fails because token_network_deposit_limit is smaller than
         # channel_participant_deposit_limit.
         token_network_registry_contract.functions.createERC20TokenNetwork(
@@ -366,7 +366,7 @@ def test_create_erc20_token_network(
     channel_participant_deposit_limit: int,
     token_network_deposit_limit: int,
 ) -> None:
-    """ Create a TokenNetwork through a TokenNetworkRegistry """
+    """Create a TokenNetwork through a TokenNetworkRegistry"""
 
     assert (
         token_network_registry_contract.functions.token_to_token_networks(
@@ -410,7 +410,7 @@ def test_create_erc20_token_network_twice_fails(
     channel_participant_deposit_limit: int,
     token_network_deposit_limit: int,
 ) -> None:
-    """ Only one TokenNetwork should be creatable from a TokenNetworkRegistry """
+    """Only one TokenNetwork should be creatable from a TokenNetworkRegistry"""
 
     call_and_transact(
         token_network_registry_contract.functions.createERC20TokenNetwork(
@@ -421,7 +421,7 @@ def test_create_erc20_token_network_twice_fails(
         {"from": DEPLOYER_ADDRESS},
     )
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TNR: registry full"):
         token_network_registry_contract.functions.createERC20TokenNetwork(
             custom_token.address,
             channel_participant_deposit_limit,
@@ -438,7 +438,7 @@ def test_events(
     channel_participant_deposit_limit: int,
     token_network_deposit_limit: int,
 ) -> None:
-    """ TokenNetworkRegistry should raise an event when deploying a new TokenNetwork """
+    """TokenNetworkRegistry should raise an event when deploying a new TokenNetwork"""
 
     ev_handler = event_handler(token_network_registry_contract)
 
@@ -455,3 +455,29 @@ def test_events(
         check_token_network_created(custom_token.address, new_token_network.address),
     )
     ev_handler.check()
+
+
+@pytest.mark.usefixtures("no_token_network")
+def test_change_owner(
+    token_network_registry_contract: Contract,
+    get_accounts: Callable,
+) -> None:
+    """Address must be allowed to remove limits after if became owner"""
+    new_controller = get_accounts(1)[0]
+
+    # Must fail when controller is still DEPLOYER_ADDRESS
+    with pytest.raises(TransactionFailed, match="Can only be called by controller"):
+        call_and_transact(
+            token_network_registry_contract.functions.removeLimits(),
+            {"from": new_controller},
+        )
+
+    # Must succeed after change of controller
+    call_and_transact(
+        token_network_registry_contract.functions.changeController(new_controller),
+        {"from": DEPLOYER_ADDRESS},
+    )
+    call_and_transact(
+        token_network_registry_contract.functions.removeLimits(),
+        {"from": new_controller},
+    )
